==> img0ch-3.0.0.tar.bz2: img0ch/_template/type/not_found.cs <==
<?xml version="1.0" encoding="shift_jis"?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1//EN"
  "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd">

<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="ja">
<head>
<title><?cs var:html_escape(BBS_TITLE) ?> - w肳ꂽXbhǂݍނƂo܂</title>
<meta http-equiv="Content-Type" content="text/html; charset=shift_jis" />
<meta http-equiv="Content-Script-Type" content="text/javascript" />
<meta http-equiv="Content-Style-Type" content="text/css" />
<meta name="generator" content="<?cs var:html_escape(VERSION) ?>" />
<link media="screen" href="<?cs var:html_escape(StaticURI) ?>/tdiary/base.css" rel="stylesheet" />
<link media="screen" href="<?cs var:html_escape(StaticURI) ?>/tdiary/<?cs if:BBS_TYPE_THEME ?><?cs var:html_escape(BBS_TYPE_THEME) ?>/<?cs var:html_escape(BBS_TYPE_THEME) ?>.css<?cs else ?>default/default.css<?cs /if ?>" rel="stylesheet" />
<style type="text/css">
@charset "shift_jis";
fieldset { border: 0px; }
img { border: 0px; }
.center { text-align:center !important;  }
.clear { clear: both !important; }
.icon-align { vertical-align: top; }
.image { border: none; float: left; margin-right: 4px; margin-bottom: 1px; }
.right { text-align: right !important; }
.res_body {
  font-size: 12pt;
  font-family: "Mona","IPA i[ PSVbN","IPA MONAPGOTHIC","MS PGothic","lr oSVbN","MS P޼","MS PSVbN",sans-serif;
  line-height: 120% !important;
}
</style>
</head>
<body>

<h1>ERROR!</h1>
<hr class="sep" />

<?cs if:IsError ?>

<div class="day" id="error">
 <h2><span class="title"><?cs var:html_escape(ShortErrorStr) ?></span></h2>
 <div class="body">
  <div class="caption"><?cs var:html_escape(LongErrorStr) ?></div>
  <div class="section">
   <p>
    G[߁Ap邱Ƃo܂B
    <a href="<?cs var:html_escape(BBSURI) ?>/">fɖ߂</a>
   </p>
  </div>
 </div>
</div>

<?cs elif:IsPooled ?>

<?cs if:Banner ?>
<hr class="sep" />
<div class="day" id="mainBanner">
 <h2><span class="title">m</span></h2>
 <div class="body">
  <div class="section">
   <?cs var:Banner ?>
  </div>
 </div>
</div>
<?cs /if ?>

<div class="day">
 <h2 class="thread_header">
  <span class="title thread_subject">u<?cs var:Subject ?>v͑q(v[)ɕۊǂĂ܂</span>
 </h2>
 <div class="form">
  <div class="caption">
   <a href="<?cs var:html_escape(BBSURI) ?>/">fɖ߂遡</a>
   <a href="<?cs var:html_escape(ReadCGIURI) ?>/">S</a>
   <a href="<?cs var:html_escape(ReadCGIURI) ?>/1-100">1-</a>
   <a href="<?cs var:html_escape(ReadCGIURI) ?>/l50">ŐV50</a>
  </div>
  <div class="section">
   <p>
   ݕ\ĂXbhdat̃X<strong><?cs var:html_escape(ResCount) ?></strong>A傫<strong><?cs var:html_escape(DatKByteSize) ?></strong>KBłB<br />
   <?cs if:IsArchived ?>܂AߋOqɂ<a href="<?cs var:html_escape(Archive) ?>/<?cs var:html_escape(Token1) ?>/<?cs var:html_escape(Token2) ?>/<?cs var:html_escape(KEY) ?>.html"><?cs var:html_escape(KEY) ?>.html</a>ƂĕۑĂ܂B<?cs /if ?>
   </p>
  </div>
 </div>
 <div class="body thread_body" id="t_<?cs var:html_escape(KEY) ?>">
  <?cs each:res = Thread ?>
   <div class="section" id="r_<?cs var:html_escape(res.resno) ?>">
    <div class="caption res_header">
     <?cs var:html_escape(res.resno) ?>
     OF<span class="commentator">
     <?cs if:res.mail ?>
      <a href="mailto:<?cs var:html_escape(res.mail) ?>" rel="nofollow"><b><?cs var:res.name ?></b></a>
     <?cs else ?>
      <span class="nomail"><b><?cs var:res.name ?></b></span>
     <?cs /if ?>
     </span>:<span class="commenttime"><?cs var:res.date ?></span>
    </div>
    <p class="res_body"><?cs var:res.text ?></p>
   </div>
  <?cs /each ?>
 </div>
</div>

<?cs else ?>

<div class="day" id="error">
 <h2><span class="title">Xbh̓ǂݍ݂Ɏs܂</span></h2>
 <div class="body">
  <div class="caption">̂悤ȃXbh݂͑܂</div>
  <div class="section">
   <p>
    Xbh݂Ȃ߁Ap邱Ƃo܂B<br />
    <?cs if:IsArchived ?>ЂƂĉߋOqɂɕۑĂ<a href="<?cs var:html_escape(Archive) ?>/<?cs var:html_escape(Token1) ?>/<?cs var:html_escape(Token2) ?>/<?cs var:html_escape(KEY) ?>.html"><?cs var:html_escape(KEY) ?>.html</a>TłH<?cs else ?>ߋOqɂɂ݂Ȃ߁AXbh폜ꂽ܂B<?cs /if ?>
    <br /><br /><a href="<?cs var:html_escape(BBSURI) ?>/">fɖ߂</a>
   </p>
  </div>
 </div>
</div>

<?cs /if ?>

<hr class="sep" />
<div class="footer">
 <a href="http://img0ch.sourceforge.jp"><?cs var:html_escape(VERSION) ?></a>
</div>

</body>
</html>

==> img0ch-3.1.10.tar.bz2: img0ch/_template/type/not_found.cs <==
<?xml version="1.0" encoding="shift_jis"?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1//EN"
  "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd">

<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="ja">
<head>
<title><?cs var:html_escape(BBS_TITLE) ?> - w肳ꂽXbhǂݍނƂo܂</title>
<meta http-equiv="Content-Type" content="text/html; charset=shift_jis" />
<meta http-equiv="Content-Script-Type" content="text/javascript" />
<meta http-equiv="Content-Style-Type" content="text/css" />
<meta name="generator" content="<?cs var:html_escape(VERSION) ?>" />
<link media="screen" href="<?cs var:html_escape(StaticURI) ?>/tdiary/base.css" rel="stylesheet" />
<link media="screen" href="<?cs var:html_escape(StaticURI) ?>/tdiary/<?cs if:BBS_TYPE_THEME ?><?cs var:html_escape(BBS_TYPE_THEME) ?>/<?cs var:html_escape(BBS_TYPE_THEME) ?>.css<?cs else ?>default/default.css<?cs /if ?>" rel="stylesheet" />
<style type="text/css">
@charset "shift_jis";
fieldset { border: 0px; }
img { border: 0px; }
.center { text-align:center !important;  }
.clear { clear: both !important; }
.icon-align { vertical-align: top; }
.image { border: none; float: left; margin-right: 4px; margin-bottom: 1px; }
.right { text-align: right !important; }
.res_body {
  font-size: 12pt;
  font-family: "Mona","IPA i[ PSVbN","IPA MONAPGOTHIC","MS PGothic","lr oSVbN","MS P޼","MS PSVbN",sans-serif;
  line-height: 120% !important;
}
</style>
</head>
<body>

<h1>ERROR!</h1>
<hr class="sep" />

<?cs if:IsError ?>

<div class="day" id="error">
 <h2><span class="title"><?cs var:html_escape(ShortErrorStr) ?></span></h2>
 <div class="body">
  <div class="caption"><?cs var:html_escape(LongErrorStr) ?></div>
  <div class="section">
   <p>
    G[߁Ap邱Ƃo܂B
    <a href="<?cs var:html_escape(BBSURI) ?>/">fɖ߂</a>
   </p>
  </div>
 </div>
</div>

<?cs elif:IsPooled ?>

<?cs if:Banner ?>
<hr class="sep" />
<div class="day" id="mainBanner">
 <h2><span class="title">m</span></h2>
 <div class="body">
  <div class="section">
   <?cs var:Banner ?>
  </div>
 </div>
</div>
<?cs /if ?>

<div class="day">
 <h2 class="thread_header">
  <span class="title thread_subject">u<?cs var:html_escape(Subject) ?>v͑q(v[)ɕۊǂĂ܂</span>
 </h2>
 <div class="form">
  <div class="caption">
   <a href="<?cs var:html_escape(BBSURI) ?>/">fɖ߂遡</a>
   <a href="<?cs var:html_escape(ReadCGIURI) ?>/">S</a>
   <a href="<?cs var:html_escape(ReadCGIURI) ?>/1-100">1-</a>
   <a href="<?cs var:html_escape(ReadCGIURI) ?>/l50">ŐV50</a>
  </div>
  <div class="section">
   <p>
   ݕ\ĂXbhdat̃X<strong><?cs var:html_escape(ResCount) ?></strong>A傫<strong><?cs var:html_escape(DatKByteSize) ?></strong>KBłB<br />
   <?cs if:IsArchived ?>܂AߋOqɂ<a href="<?cs var:html_escape(Archive) ?>/<?cs var:html_escape(Token1) ?>/<?cs var:html_escape(Token2) ?>/<?cs var:html_escape(KEY) ?>.html"><?cs var:html_escape(KEY) ?>.html</a>ƂĕۑĂ܂B<?cs /if ?>
   </p>
  </div>
 </div>
 <div class="body thread_body" id="t_<?cs var:html_escape(KEY) ?>">
  <?cs each:res = Thread ?>
   <div class="section" id="r_<?cs var:html_escape(res.resno) ?>">
    <div class="caption res_header">
     <?cs var:html_escape(res.resno) ?>
     OF<span class="commentator">
     <?cs if:res.mail ?>
      <a href="mailto:<?cs var:html_escape(res.mail) ?>" rel="nofollow"><b><?cs var:res.name ?></b></a>
     <?cs else ?>
      <span class="nomail"><b><?cs var:res.name ?></b></span>
     <?cs /if ?>
     </span>:<span class="commenttime"><?cs var:res.date ?></span>
    </div>
    <p class="res_body"><?cs var:res.text ?></p>
   </div>
  <?cs /each ?>
 </div>
</div>

<?cs else ?>

<div class="day" id="error">
 <h2><span class="title">Xbh̓ǂݍ݂Ɏs܂</span></h2>
 <div class="body">
  <div class="caption">̂悤ȃXbh݂͑܂</div>
  <div class="section">
   <p>
    Xbh݂Ȃ߁Ap邱Ƃo܂B<br />
    <?cs if:IsArchived ?>ЂƂĉߋOqɂɕۑĂ<a href="<?cs var:html_escape(Archive) ?>/<?cs var:html_escape(Token1) ?>/<?cs var:html_escape(Token2) ?>/<?cs var:html_escape(KEY) ?>.html"><?cs var:html_escape(KEY) ?>.html</a>TłH<?cs else ?>ߋOqɂɂ݂Ȃ߁AXbh폜ꂽ܂B<?cs /if ?>
    <br /><br /><a href="<?cs var:html_escape(BBSURI) ?>/">fɖ߂</a>
   </p>
  </div>
 </div>
</div>

<?cs /if ?>

<hr class="sep" />
<div class="footer">
 <a href="http://img0ch.sourceforge.jp"><?cs var:html_escape(VERSION) ?></a>
</div>

</body>
</html>
